/**
 * @file PresentationUI.js
 */
import { useState, useEffect, Component } from 'react';
import { useParams } from 'react-router-dom';
import { Pie } from "react-chartjs-2";
import 'chart.js/auto'
import './PresentationUI.css'
import axios from 'axios';
import './Modal.js';

export class PresentationTile extends Component {
    constructor(props) {
        super(props);
        this.state = props.data;
    }
    state = { 
        id: -1,
        title: "",
        display_mode: "",
    }

    renderSwitch() {
        switch (this.state.display_mode) {
            case 'pie-x-by-y':
                return (<Pie data={this.props.info}/>);
            case 'bar':
            case 'line':
            default:
                return (<div>Unrecognized display mode</div>);
        }
    }

    /**
     * @description Runs when the component is mounted and updates the tile in set intervals
     * @returns an function that runs in intervals 
     */
    componentDidMount() {
        const interval = setInterval(() => {
            axios
            .get('http://localhost:8000/api/tiles/' + this.state.id)
            .then((res) => {this.setState({title: res.data.title})})
            .catch((err) => console.log(err));
          }, this.state.refresh_rate);
        return () => clearInterval(interval);
    }

    /**
     * @description Is called when the component is set to be rendered
     */
    render() {
        return ( 
            <div className="tile">
                <div className="tile-header">
                    <h3>{this.state.title}</h3>
                </div>
                {this.renderSwitch()}
            </div>
        );
    }

    
}

/**
 * @description Displays all the tiles for a given window ID
 * @returns The presentation UI
 */
const PresentationUI = () => {
    const [tiles, setTiles] = useState([]);
    const [modal, setModal] = useState(false);
    const params = useParams();

    // runs on load + update
    useEffect( () => {
        axios
        .get('http://localhost:8000/api/tiles/')
        .then((res) => { setTiles(res.data) })
        .catch((err) => console.log(err))
    }, []);


    /**
     * @description Render the tiles for a window
     * @returns An array of a JSX element for each tile.
     */
    const renderTiles = () => {
        const data = tiles.filter(e => e.window_id == params.id);
        
        return (data.sort((a, b) => a.order-b.order)).map( (tile) => (
            <PresentationTile data={tile} info={nums} key={tile.id}/>
        ));
    }

    return (     
        <div className="PresentationUI">
            { renderTiles() }
        </div>
        );
}
 
export default PresentationUI;

