/**
 * Login siden til applikasjonen, inneholder to funksjoner som sier
 * noe om hvordan den skal se ut og funksjonalitet
 * 
 * @file login.js
 */

import React, { useState } from 'react';
import PropTypes from 'prop-types';
import axios from 'axios';

/**
 * Gjør en spørring som tar innformasjonen til brukeren, får en 
 * token returnert hvis brukeren blir autorisert
 * 
 * @param {*} creds Logininnformasjonen til brukeren 
 * @returns En token som blir returnert fra spørringen
 */
async function loginUser(creds) {
    const token = await axios.post('http://localhost:8080/login', creds)
    .then((response) => {
        return(response.data.token)
    })
    return(token);
}

/**
 * Deler av følgende kode er hentet herfra:
 * //https://www.digitalocean.com/community/tutorials/how-to-add-login-authentication-to-react-applications
 * og:
 * https://contactmentor.com/login-form-react-js-code/
 * 
 * Loginsiden, håndterer innlogging igjennom NTNU sin innloggingsserver
 * 
 * @param {*} setToken Staten som skal få innformasjon lagret
 * @returns JSX koden til loginsiden
 */
export default function Login( { setToken }) {
    /**
     * Tar brukernavnet og passordet og gjør en spørringen gjennom loginUser funksjonen
     * 
     * @param {*} e Eventen som blir utløst
     */
    const handleSubmit = async e => {
        e.preventDefault();
        
        var { username, password } = document.forms[0];

        setToken(await loginUser({
            username: username.value,
            password: password.value
        }))
    }

    return (
        <div> 
            <h1>Log in:</h1>
        <form onSubmit={handleSubmit}>
            <label>
                <div>Username:</div>
                <input type="text" name="username" required />
            </label>
            <label>
                <div>Password:</div>
                <input type="password" name="password" required />
            </label>
            <button type="submit">Log in</button>
        </form>
        </div>
    )
}

Login.propTypes = {
    setToken: PropTypes.func.isRequired
}