/**
 * @description Inneholder funksjonalitet til hvordan tokens skal bli håndtert.
 * disse er delt inn i flere funksjoner useToken, deleteToken og checkToken.
 * 
 * Noen deler av denne koden er blitt inspirert av kode i følgende link:
 * https://www.digitalocean.com/community/tutorials/how-to-add-login-authentication-to-react-applications
 * 
 * @file tokenHandling.js
 */

import { useState } from 'react';
import axios from 'axios';

/**
 * En react hook, som henter inn tokenen og setter den i en react state, lagrer
 * denne staten og returnerer en token, samt å setter den tokenen inn i setToken 
 * variablen
 * 
 * @returns 
 */
export function useToken() {
    const getToken = () => {
        const tokenString = localStorage.getItem('token');
        const userToken = JSON.parse(tokenString);
        return userToken
    };

    const [token, setToken] = useState(getToken()); ///< Setter tokenen inn i en react state

    const saveToken = userToken => {
        localStorage.setItem('token', JSON.stringify(userToken));
        setToken(userToken.token);
        window.location.reload();
    }

    return {
        setToken: saveToken,
        token
    }
}

export const deleteToken = async (token) => {
    localStorage.removeItem("token");
    window.location.reload();
    
    console.log(token);
}

/**
 * Asynkron funksjon som sjekker om tokenen er gyldig. Denn gjør dette ved å gjøre en spørring
 * på APIet, den returnerer enten true eller false, hvis den er true så skjer det ingen ting, 
 * hvis den er false så vil den bli slettet fra lokallagringen.
 * 
 * @param checkToken Tokenen som skal bli sjekket, tokenen som ligger lagret i lokallagring
 */
export const checkToken = async (checkToken) => {
    const getToken = {
        token: checkToken,
    }

    const check = await axios
    .post('http://localhost:8080/getToken', getToken)
    .then((res) => { 
        return res.data;
    })
    .catch((err) => console.log(err))

    if (!check) {
        localStorage.removeItem("token");
        window.location.reload();
    }
}